"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

var _docopt = require("docopt");

var _exit_with_error = _interopRequireDefault(require("./util/exit_with_error"));

var _package = _interopRequireDefault(require("../package.json"));

var _run = _interopRequireDefault(require("./run"));

var _generate_config = _interopRequireDefault(require("./generate_config"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const usage = `\
Usage:
  dependency-lint [--auto-correct] [--generate-config] [--format <format>]

Options:
  --auto-correct       Moves mislabeled modules and removes unused modules
  --format <format>    Select the formatter: json, minimal (default), summary
  -h, --help           Show this screen
  --generate-config    Generate a configuration file
  -v, --version        Show version\
`;

async function _default() {
  try {
    const options = (0, _docopt.docopt)(usage, {
      version: _package.default.version
    });
    const fn = options['--generate-config'] ? _generate_config.default : _run.default;
    const format = options['--format'] || 'minimal';

    if (!['json', 'minimal', 'summary'].includes(format)) {
      throw new Error(`Invalid format: '${format}'. Valid formats: json, minimal, or summary`);
    }

    await fn({
      autoCorrect: options['--auto-correct'],
      format: format
    });
  } catch (error) {
    (0, _exit_with_error.default)(error);
  }
}